@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertDistImage;
 
 our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,9 +16,18 @@ with (
 );
 
 has hosting => (is => 'rw', default => sub {'metacpan'});
+has include_files => (is => 'rw');
+has exclude_files => (is => 'rw');
+has include_file_pattern => (is => 'rw');
+has exclude_file_pattern => (is => 'rw');
+
+sub mvp_multivalue_args { qw(include_files exclude_files) }
 
 use namespace::autoclean;
 
+use File::Slurper qw(read_binary);
+use URI;
+
 sub munge_files {
     my $self = shift;
 
@@ -56,7 +65,6 @@ sub munge_files {
             $self->log_fatal(["Repository URL is not bitbucket"]) unless ($bitbucket_user, $bitbucket_repo) = $url =~ m!bitbucket\.org/([^/]+)/([^/]+)\.git!;
         }
     } elsif ($hosting eq 'data') {
-        $self->log_fatal(["Not yet implemented"]);
     } else {
         $self->log_fatal(["Unknown hosting value '%s'", $hosting]);
     }
@@ -100,12 +108,50 @@ sub munge_files {
                 $bitbucket_repo,
                 $path,
             );
+        } elsif ($hosting eq 'data') {
+            my $ct;
+            if ($path =~ /\.jpe?g\z/) {
+                $ct = "image/jpeg";
+            } else {
+                $path =~ /\.(\w+)\z/ or die;
+                $ct = "image/$1";
+            }
+            $url = URI->new("data:");
+            $url->media_type($ct);
+            $url->data(read_binary($path));
+            $url = "$url";
         }
 
         "=begin html\n\n<img src=\"$url\" />\n\n=end html\n\n";
     };
 
+  FILE:
     for my $file (@{ $self->found_files }) {
+        if ($self->include_files && @{ $self->include_files }) {
+            unless (grep {$_ eq $file->name} @{$self->include_files}) {
+                $self->log_debug(["Skipped file %s (not in include_files)", $file->name]);
+                next FILE;
+            }
+        }
+        if ($self->exclude_files && @{ $self->exclude_files }) {
+            if (grep {$_ eq $file->name} @{$self->exclude_files}) {
+                $self->log_debug(["Skipped file %s (in include_files)", $file->name]);
+                next FILE;
+            }
+        }
+        if (my $pat = $self->include_file_pattern) {
+            unless ($file->name =~ /$pat/) {
+                $self->log_debug(["Skipped file %s (doesn't match include_file_pattern)", $file->name]);
+                next FILE;
+            }
+        }
+        if (my $pat = $self->exclude_file_pattern) {
+            if ($file->name =~ /$pat/) {
+                $self->log_debug(["Skipped file %s (matches exclude_file_pattern)", $file->name]);
+                next FILE;
+            }
+        }
+
         my $content = $file->content;
         if ($content =~ s{^#\s*IMAGE(?:\s*:\s*|\s+)(\S.+?)\s*$}{$code_insert->($1)}egm) {
             $self->log(["inserting images into '%s'", $file->name]);
@@ -130,7 +176,7 @@ Dist::Zilla::Plugin::InsertDistImage - Insert images contained in distribution i
 
 =head1 VERSION
 
-This document describes version 0.001 of Dist::Zilla::Plugin::InsertDistImage (from Perl distribution Dist-Zilla-Plugin-InsertDistImage), released on 2016-07-13.
+This document describes version 0.002 of Dist::Zilla::Plugin::InsertDistImage (from Perl distribution Dist-Zilla-Plugin-InsertDistImage), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
@@ -140,8 +186,12 @@ In F<dist.ini>:
 
  [InsertDistImages]
  ;hosting=metacpan
+ ;include_files=...
+ ;exclude_files=...
+ ;include_file_pattern=...
+ ;exclude_file_pattern=...
 
-In F<lib/Foo.pm> or F<bin/>:
+In F<lib/Foo.pm> or F<bin/bar>:
 
  ...
 
@@ -224,6 +274,14 @@ C<data:> URIs where the image data is directly embedded in the URL.
 
 =back
 
+=head2 include_files => str+
+
+=head2 exclude_files => str+
+
+=head2 include_file_pattern => re
+
+=head2 exclude_file_pattern => re
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-InsertDistImage>.
